@@ -21,18 +21,18 @@
  ([CRGMW95])
 """
 
-__revision__ = "$Id: fmes.py,v 1.20 2004/09/03 10:06:38 alf Exp $"
+__revision__ = "$Id: fmes.py,v 1.22 2005-04-26 15:21:13 syt Exp $"
 
-from logilab.xmldiff.objects import NT_ROOT, NT_NODE, NT_ATTN, NT_ATTV, \
+from xmldiff.objects import NT_ROOT, NT_NODE, NT_ATTN, NT_ATTV, \
      NT_TEXT, NT_COMM, N_TYPE, N_NAME, N_VALUE, N_CHILDS, N_PARENT, N_ISSUE, \
      N_XNUM, NSIZE, A_DESC, A_N1, A_N2, FALSE, TRUE, \
      node_repr, get_labels, get_ancestors, caract, make_bfo_list, \
      insert_node, delete_node, rename_node, get_pos, \
      f_xpath, nb_attrs, xml_print
-from logilab.xmldiff.mydifflib import lcs2, quick_ratio
-from logilab.xmldiff.misc import intersection, in_ref, index_ref
+from xmldiff.mydifflib import lcs2, quick_ratio
+from xmldiff.misc import intersection, in_ref, index_ref
 # c extensions
-from logilab.xmldiff.maplookup import has_couple , partner, fmes_init, \
+from xmldiff.maplookup import has_couple , partner, fmes_init, \
      fmes_node_equal, match_end, fmes_end
 
 # node's attributes for fmes algorithm
@@ -372,8 +372,7 @@ class FmesCorrector:
                     n1[N_VALUE] = new_name
                     self.add_action(['append', f_xpath(n2), n1])
                 else:
-                    self.add_action(['move', n1, n2])
-                    
+                    self.add_action(['move-first', n1, n2])
         elif k <= nb_attrs(n2):
             self.add_action(['move-first', n1, n2])
         else:
